@@ -9,6 +9,8 @@
 #include <QAbstractListModel>
 #include <QQmlParserStatus>
 
+#include <qqmlregistration.h>
+
 #include <KService>
 
 class QDBusInterface;
@@ -19,6 +21,7 @@ class QDBusInterface;
 class ToolsModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
 public:
     enum Roles {
@@ -46,5 +49,5 @@ private:
         QString shortcut;
         KService::Ptr service;
     };
-    QVector<Entry> m_entries;
+    QList<Entry> m_entries;
 };
